from .async_base_client_open_telemetry import AsyncBaseClientOpenTelemetry
from .async_client import AsyncGQLClient
from .add_external_model import AddExternalModel, AddExternalModelAddExternalModel
from .add_hf_model import AddHFModel, AddHFModelImportHfModel
from .add_model import AddModel, AddModelAddModel, AddModelAddModelBackbone
from .add_remote_env import AddRemoteEnv, AddRemoteEnvAddRemoteEnv
from .attach_model_to_use_case import AttachModelToUseCase, AttachModelToUseCaseAttachModel
from .base_client_open_telemetry import BaseClientOpenTelemetry
from .base_model import BaseModel, Upload
from .cancel_ab_campaign import CancelABCampaign
from .cancel_job import CancelJob, CancelJobCancelJob
from .client import GQLClient
from .create_ab_campaign import CreateAbCampaign, CreateAbCampaignCreateAbCampaign
from .create_custom_recipe import CreateCustomRecipe, CreateCustomRecipeCreateCustomRecipe
from .create_grader import CreateGrader, CreateGraderCreateGrader
from .create_job import CreateJob, CreateJobCreateJob
from .create_judge import CreateJudge, CreateJudgeCreateJudge
from .create_metric import CreateMetric, CreateMetricCreateMetric
from .create_prebuilt_judge import CreatePrebuiltJudge, CreatePrebuiltJudgeCreatePrebuiltJudge
from .create_role import CreateRole, CreateRoleCreateRole
from .create_team import CreateTeam, CreateTeamCreateTeam
from .create_use_case import CreateUseCase, CreateUseCaseCreateUseCase
from .create_user import CreateUser, CreateUserCreateUser
from .delete_custom_recipe import DeleteCustomRecipe
from .delete_dataset import DeleteDataset
from .delete_grader import DeleteGrader, DeleteGraderDeleteGrader
from .delete_judge import DeleteJudge, DeleteJudgeDeleteJudge
from .delete_user import DeleteUser, DeleteUserDeleteUser
from .deploy_model import DeployModel
from .describe_ab_campaign import DescribeAbCampaign, DescribeAbCampaignAbCampaign, DescribeAbCampaignAbCampaignReport
from .describe_dataset import DescribeDataset, DescribeDatasetDataset
from .describe_interaction import DescribeInteraction, DescribeInteractionCompletion
from .describe_job import DescribeJob, DescribeJobJob
from .describe_metric import DescribeMetric, DescribeMetricMetric
from .describe_metric_admin import DescribeMetricAdmin, DescribeMetricAdminMetric
from .describe_model import DescribeModel, DescribeModelModel, DescribeModelModelBackbone
from .describe_model_admin import DescribeModelAdmin, DescribeModelAdminModel, DescribeModelAdminModelBackbone
from .describe_use_case import DescribeUseCase, DescribeUseCaseUseCase
from .enums import AbcampaignStatus, AuthProviderKind, BillingCycle, CompletionGroupBy, CompletionSource, ComputePoolCapability, DatasetKind, DatasetSource, DateBucketUnit, ExternalModelProviderName, FeedbackType, GraderTypeEnum, HarmonyStatus, JobArtifactKind, JobKind, JobStatus, JobStatusOutput, JudgeCapability, MetricAggregation, MetricKind, MetricScoringType, ModelKindFilter, ModelOnline, ModelserviceStatus, OpenAIModel, PrebuiltCriteriaKey, Protocol, ProviderName, RemoteEnvStatus, SelectionTypeInput, SortDirection, TimeseriesInterval, UnitPosition
from .exceptions import GraphQLClientError, GraphQLClientGraphQLError, GraphQLClientGraphQLMultiError, GraphQLClientHttpError, GraphQLClientInvalidResponseError
from .fragments import AbCampaignCreateData, AbCampaignDetailData, AbCampaignDetailDataMetric, AbCampaignDetailDataModels, AbCampaignDetailDataUseCase, AbCampaignReportData, AbCampaignReportDataVariants, AbCampaignReportDataVariantsComparisons, AbCampaignReportDataVariantsComparisonsVariant, AbCampaignReportDataVariantsInterval, AbCampaignReportDataVariantsVariant, CompletionComparisonFeedbackData, CompletionComparisonFeedbackDataModel, CompletionData, CompletionDataChatMessages, CompletionDataComparisonFeedbacks, CompletionDataComparisonFeedbacksMetric, CompletionDataComparisonFeedbacksOtherCompletion, CompletionDataComparisonFeedbacksPreferedCompletion, CompletionDataComparisonFeedbacksUsecase, CompletionDataDirectFeedbacks, CompletionDataDirectFeedbacksMetric, CompletionDataLabels, CompletionDataMetadata, CompletionDataMetadataUsage, CompletionDataModel, CustomRecipeData, CustomRecipeDataCreatedBy, CustomRecipeDataLabels, DatasetData, DatasetDataMetricsUsage, DatasetDataMetricsUsageMetric, GraderData, GraderDataGraderConfigCustomConfigOutput, GraderDataGraderConfigJudgeConfigOutput, GraderDataGraderConfigJudgeConfigOutputExamples, GraderDataGraderConfigJudgeConfigOutputExamplesInput, GraderDataGraderConfigJudgeConfigOutputModel, GraderDataGraderConfigPrebuiltConfigOutput, GraderDataGraderConfigPrebuiltConfigOutputModel, GraderDataGraderConfigPrebuiltConfigOutputPrebuiltCriteria, GraderDataGraderConfigRemoteConfigOutput, GraderDataMetric, GraderDataUseCase, HarmonyGroupData, HarmonyGroupDataComputePool, HarmonyGroupDataOnlineModels, JobData, JobDataCreatedBy, JobDataDetails, JobDataDetailsArtifacts, JobDataRecipe, JobDataStages, JobDataStagesInfoBatchInferenceJobStageOutput, JobDataStagesInfoEvalJobStageOutput, JobDataStagesInfoTrainingJobStageOutput, JobDataUseCase, JobStageOutputData, JobStageOutputDataInfoBatchInferenceJobStageOutput, JobStageOutputDataInfoEvalJobStageOutput, JobStageOutputDataInfoTrainingJobStageOutput, JudgeData, JudgeDataExamples, JudgeDataExamplesInput, JudgeDataMetric, JudgeDataModel, MetricData, MetricDataAdmin, MetricDataAdminUseCases, MetricWithContextData, ModelData, ModelDataAdmin, ModelDataAdminUseCases, ModelDataComputeConfig, ModelServiceData, ModelServiceDataModel, ModelServiceDataModelBackbone, RemoteEnvData, UseCaseData, UseCaseDataMetrics, UseCaseDataModelServices, UseCaseDataShares, UseCaseDataSharesRole, UseCaseDataSharesTeam, UserData, UserDataTeams, UserDataTeamsRole, UserDataTeamsTeam
from .get_custom_recipe import GetCustomRecipe, GetCustomRecipeCustomRecipe
from .get_grader import GetGrader, GetGraderGrader
from .get_judge import GetJudge, GetJudgeJudge
from .input_types import AbcampaignCreate, AbCampaignFilter, AddExternalModelInput, AddHFModelInput, AddModelInput, AnthropicProviderDataInput, ApiKeyCreate, ArtifactFilter, AttachModel, AzureProviderDataInput, CompletionComparisonFilterInput, CompletionFeedbackFilterInput, CompletionLabelValue, CompletionsByFilters, CompletionsById, CreateRecipeInput, CreateToolProviderInput, CursorPageInput, CustomConfigInput, CustomRecipeFilterInput, DatasetCompletionQuery, DatasetCreate, DatasetCreateFromFilters, EmojiInput, FeedbackAddInput, FeedbackFilterInput, FeedbackUpdateInput, FromGroupsQuery, GlobalUsageFilterInput, GoogleProviderDataInput, GraderConfigInput, GraderCreateInput, GraderUpdateInput, GroupSelection, GroupSelectionQuery, JobArtifactFilter, JobInput, JudgeConfigInput, JudgeCreate, JudgeExampleInput, JudgeExampleInputTurnEntry, JudgeUpdate, LabelFilter, LabelInput, ListCompletionsFilterInput, ListJobsFilterInput, MetricCreate, MetricGetOrCreate, MetricLink, MetricTrendInput, MetricUnlink, ModelComputeConfigInput, ModelFilter, ModelPlacementInput, ModelProviderDataInput, ModelServiceDisconnect, ModelServiceFilter, NvidiaProviderDataInput, OpenAIProviderDataInput, OrderPair, PrebuiltConfigInput, PrebuiltJudgeCreate, RemoteConfigInput, RemoteEnvCreate, ResizePartitionInput, RoleCreate, SampleConfig, SystemPromptTemplateCreate, SystemPromptTemplateUpdate, TeamCreate, TeamMemberRemove, TeamMemberSet, TimeRange, TimeseriesInput, UnitConfigInput, UpdateCompletion, UpdateModelService, UpdateRecipeInput, UpdateToolProviderInput, UsageFilterInput, UsagePerUseCaseFilterInput, UseCaseCreate, UseCaseFilter, UseCaseMetadataInput, UseCaseSettingsInput, UseCaseShareInput, UseCaseShares, UseCaseUpdate, UserCreate, UserCreateTeamWithRole, WidgetInput
from .link_metric import LinkMetric, LinkMetricLinkMetric
from .list_ab_campaigns import ListAbCampaigns, ListAbCampaignsAbCampaigns
from .list_compute_pools import ListComputePools, ListComputePoolsComputePools, ListComputePoolsComputePoolsHarmonyGroups
from .list_custom_recipes import ListCustomRecipes, ListCustomRecipesCustomRecipes
from .list_datasets import ListDatasets, ListDatasetsDatasets
from .list_graders import ListGraders, ListGradersGraders
from .list_grouped_interactions import ListGroupedInteractions, ListGroupedInteractionsCompletionsGrouped, ListGroupedInteractionsCompletionsGroupedNodes, ListGroupedInteractionsCompletionsGroupedNodesCompletions, ListGroupedInteractionsCompletionsGroupedNodesCompletionsNodes, ListGroupedInteractionsCompletionsGroupedNodesDirectFeedbacksStats, ListGroupedInteractionsCompletionsGroupedNodesDirectFeedbacksStatsMetric, ListGroupedInteractionsCompletionsGroupedPageInfo
from .list_harmony_groups import ListHarmonyGroups, ListHarmonyGroupsHarmonyGroups
from .list_interactions import ListInteractions, ListInteractionsCompletions, ListInteractionsCompletionsNodes, ListInteractionsCompletionsPageInfo
from .list_jobs import ListJobs, ListJobsJobs, ListJobsJobsNodes, ListJobsJobsPageInfo
from .list_judge_versions import ListJudgeVersions, ListJudgeVersionsJudgeVersions
from .list_judges import ListJudges, ListJudgesJudges
from .list_metrics import ListMetrics, ListMetricsMetrics
from .list_models import ListModels, ListModelsModels, ListModelsModelsBackbone
from .list_permissions import ListPermissions
from .list_remote_envs import ListRemoteEnvs, ListRemoteEnvsRemoteEnvs
from .list_roles import ListRoles, ListRolesRoles
from .list_teams import ListTeams, ListTeamsTeams
from .list_use_cases import ListUseCases, ListUseCasesUseCases
from .list_users import ListUsers, ListUsersUsers
from .load_dataset import LoadDataset, LoadDatasetCreateDataset
from .lock_grader import LockGrader, LockGraderLockGrader
from .me import Me, MeMe, MeMeApiKeys
from .remove_remote_env import RemoveRemoteEnv
from .remove_team_member import RemoveTeamMember, RemoveTeamMemberRemoveTeamMember
from .share_use_case import ShareUseCase, ShareUseCaseShareUseCase
from .terminate_model import TerminateModel
from .test_remote_env import TestRemoteEnv, TestRemoteEnvTestRemoteEnvRemoteEnvTestOffline, TestRemoteEnvTestRemoteEnvRemoteEnvTestOnline
from .unlink_metric import UnlinkMetric
from .update_custom_recipe import UpdateCustomRecipe, UpdateCustomRecipeUpdateCustomRecipe
from .update_grader import UpdateGrader, UpdateGraderUpdateGrader
from .update_judge import UpdateJudge, UpdateJudgeUpdateJudge
from .update_model import UpdateModel, UpdateModelUpdateModelService
from .update_model_compute_config import UpdateModelComputeConfig, UpdateModelComputeConfigUpdateModelComputeConfig
from .update_user import UpdateUser, UpdateUserSetTeamMember, UpdateUserSetTeamMemberRole, UpdateUserSetTeamMemberTeam, UpdateUserSetTeamMemberUser
__all__ = ['AbCampaignCreateData', 'AbCampaignDetailData', 'AbCampaignDetailDataMetric', 'AbCampaignDetailDataModels', 'AbCampaignDetailDataUseCase', 'AbCampaignFilter', 'AbCampaignReportData', 'AbCampaignReportDataVariants', 'AbCampaignReportDataVariantsComparisons', 'AbCampaignReportDataVariantsComparisonsVariant', 'AbCampaignReportDataVariantsInterval', 'AbCampaignReportDataVariantsVariant', 'AbcampaignCreate', 'AbcampaignStatus', 'AddExternalModel', 'AddExternalModelAddExternalModel', 'AddExternalModelInput', 'AddHFModel', 'AddHFModelImportHfModel', 'AddHFModelInput', 'AddModel', 'AddModelAddModel', 'AddModelAddModelBackbone', 'AddModelInput', 'AddRemoteEnv', 'AddRemoteEnvAddRemoteEnv', 'AnthropicProviderDataInput', 'ApiKeyCreate', 'ArtifactFilter', 'AsyncBaseClientOpenTelemetry', 'AsyncGQLClient', 'AttachModel', 'AttachModelToUseCase', 'AttachModelToUseCaseAttachModel', 'AuthProviderKind', 'AzureProviderDataInput', 'BaseClientOpenTelemetry', 'BaseModel', 'BillingCycle', 'CancelABCampaign', 'CancelJob', 'CancelJobCancelJob', 'CompletionComparisonFeedbackData', 'CompletionComparisonFeedbackDataModel', 'CompletionComparisonFilterInput', 'CompletionData', 'CompletionDataChatMessages', 'CompletionDataComparisonFeedbacks', 'CompletionDataComparisonFeedbacksMetric', 'CompletionDataComparisonFeedbacksOtherCompletion', 'CompletionDataComparisonFeedbacksPreferedCompletion', 'CompletionDataComparisonFeedbacksUsecase', 'CompletionDataDirectFeedbacks', 'CompletionDataDirectFeedbacksMetric', 'CompletionDataLabels', 'CompletionDataMetadata', 'CompletionDataMetadataUsage', 'CompletionDataModel', 'CompletionFeedbackFilterInput', 'CompletionGroupBy', 'CompletionLabelValue', 'CompletionSource', 'CompletionsByFilters', 'CompletionsById', 'ComputePoolCapability', 'CreateAbCampaign', 'CreateAbCampaignCreateAbCampaign', 'CreateCustomRecipe', 'CreateCustomRecipeCreateCustomRecipe', 'CreateGrader', 'CreateGraderCreateGrader', 'CreateJob', 'CreateJobCreateJob', 'CreateJudge', 'CreateJudgeCreateJudge', 'CreateMetric', 'CreateMetricCreateMetric', 'CreatePrebuiltJudge', 'CreatePrebuiltJudgeCreatePrebuiltJudge', 'CreateRecipeInput', 'CreateRole', 'CreateRoleCreateRole', 'CreateTeam', 'CreateTeamCreateTeam', 'CreateToolProviderInput', 'CreateUseCase', 'CreateUseCaseCreateUseCase', 'CreateUser', 'CreateUserCreateUser', 'CursorPageInput', 'CustomConfigInput', 'CustomRecipeData', 'CustomRecipeDataCreatedBy', 'CustomRecipeDataLabels', 'CustomRecipeFilterInput', 'DatasetCompletionQuery', 'DatasetCreate', 'DatasetCreateFromFilters', 'DatasetData', 'DatasetDataMetricsUsage', 'DatasetDataMetricsUsageMetric', 'DatasetKind', 'DatasetSource', 'DateBucketUnit', 'DeleteCustomRecipe', 'DeleteDataset', 'DeleteGrader', 'DeleteGraderDeleteGrader', 'DeleteJudge', 'DeleteJudgeDeleteJudge', 'DeleteUser', 'DeleteUserDeleteUser', 'DeployModel', 'DescribeAbCampaign', 'DescribeAbCampaignAbCampaign', 'DescribeAbCampaignAbCampaignReport', 'DescribeDataset', 'DescribeDatasetDataset', 'DescribeInteraction', 'DescribeInteractionCompletion', 'DescribeJob', 'DescribeJobJob', 'DescribeMetric', 'DescribeMetricAdmin', 'DescribeMetricAdminMetric', 'DescribeMetricMetric', 'DescribeModel', 'DescribeModelAdmin', 'DescribeModelAdminModel', 'DescribeModelAdminModelBackbone', 'DescribeModelModel', 'DescribeModelModelBackbone', 'DescribeUseCase', 'DescribeUseCaseUseCase', 'EmojiInput', 'ExternalModelProviderName', 'FeedbackAddInput', 'FeedbackFilterInput', 'FeedbackType', 'FeedbackUpdateInput', 'FromGroupsQuery', 'GQLClient', 'GetCustomRecipe', 'GetCustomRecipeCustomRecipe', 'GetGrader', 'GetGraderGrader', 'GetJudge', 'GetJudgeJudge', 'GlobalUsageFilterInput', 'GoogleProviderDataInput', 'GraderConfigInput', 'GraderCreateInput', 'GraderData', 'GraderDataGraderConfigCustomConfigOutput', 'GraderDataGraderConfigJudgeConfigOutput', 'GraderDataGraderConfigJudgeConfigOutputExamples', 'GraderDataGraderConfigJudgeConfigOutputExamplesInput', 'GraderDataGraderConfigJudgeConfigOutputModel', 'GraderDataGraderConfigPrebuiltConfigOutput', 'GraderDataGraderConfigPrebuiltConfigOutputModel', 'GraderDataGraderConfigPrebuiltConfigOutputPrebuiltCriteria', 'GraderDataGraderConfigRemoteConfigOutput', 'GraderDataMetric', 'GraderDataUseCase', 'GraderTypeEnum', 'GraderUpdateInput', 'GraphQLClientError', 'GraphQLClientGraphQLError', 'GraphQLClientGraphQLMultiError', 'GraphQLClientHttpError', 'GraphQLClientInvalidResponseError', 'GroupSelection', 'GroupSelectionQuery', 'HarmonyGroupData', 'HarmonyGroupDataComputePool', 'HarmonyGroupDataOnlineModels', 'HarmonyStatus', 'JobArtifactFilter', 'JobArtifactKind', 'JobData', 'JobDataCreatedBy', 'JobDataDetails', 'JobDataDetailsArtifacts', 'JobDataRecipe', 'JobDataStages', 'JobDataStagesInfoBatchInferenceJobStageOutput', 'JobDataStagesInfoEvalJobStageOutput', 'JobDataStagesInfoTrainingJobStageOutput', 'JobDataUseCase', 'JobInput', 'JobKind', 'JobStageOutputData', 'JobStageOutputDataInfoBatchInferenceJobStageOutput', 'JobStageOutputDataInfoEvalJobStageOutput', 'JobStageOutputDataInfoTrainingJobStageOutput', 'JobStatus', 'JobStatusOutput', 'JudgeCapability', 'JudgeConfigInput', 'JudgeCreate', 'JudgeData', 'JudgeDataExamples', 'JudgeDataExamplesInput', 'JudgeDataMetric', 'JudgeDataModel', 'JudgeExampleInput', 'JudgeExampleInputTurnEntry', 'JudgeUpdate', 'LabelFilter', 'LabelInput', 'LinkMetric', 'LinkMetricLinkMetric', 'ListAbCampaigns', 'ListAbCampaignsAbCampaigns', 'ListCompletionsFilterInput', 'ListComputePools', 'ListComputePoolsComputePools', 'ListComputePoolsComputePoolsHarmonyGroups', 'ListCustomRecipes', 'ListCustomRecipesCustomRecipes', 'ListDatasets', 'ListDatasetsDatasets', 'ListGraders', 'ListGradersGraders', 'ListGroupedInteractions', 'ListGroupedInteractionsCompletionsGrouped', 'ListGroupedInteractionsCompletionsGroupedNodes', 'ListGroupedInteractionsCompletionsGroupedNodesCompletions', 'ListGroupedInteractionsCompletionsGroupedNodesCompletionsNodes', 'ListGroupedInteractionsCompletionsGroupedNodesDirectFeedbacksStats', 'ListGroupedInteractionsCompletionsGroupedNodesDirectFeedbacksStatsMetric', 'ListGroupedInteractionsCompletionsGroupedPageInfo', 'ListHarmonyGroups', 'ListHarmonyGroupsHarmonyGroups', 'ListInteractions', 'ListInteractionsCompletions', 'ListInteractionsCompletionsNodes', 'ListInteractionsCompletionsPageInfo', 'ListJobs', 'ListJobsFilterInput', 'ListJobsJobs', 'ListJobsJobsNodes', 'ListJobsJobsPageInfo', 'ListJudgeVersions', 'ListJudgeVersionsJudgeVersions', 'ListJudges', 'ListJudgesJudges', 'ListMetrics', 'ListMetricsMetrics', 'ListModels', 'ListModelsModels', 'ListModelsModelsBackbone', 'ListPermissions', 'ListRemoteEnvs', 'ListRemoteEnvsRemoteEnvs', 'ListRoles', 'ListRolesRoles', 'ListTeams', 'ListTeamsTeams', 'ListUseCases', 'ListUseCasesUseCases', 'ListUsers', 'ListUsersUsers', 'LoadDataset', 'LoadDatasetCreateDataset', 'LockGrader', 'LockGraderLockGrader', 'Me', 'MeMe', 'MeMeApiKeys', 'MetricAggregation', 'MetricCreate', 'MetricData', 'MetricDataAdmin', 'MetricDataAdminUseCases', 'MetricGetOrCreate', 'MetricKind', 'MetricLink', 'MetricScoringType', 'MetricTrendInput', 'MetricUnlink', 'MetricWithContextData', 'ModelComputeConfigInput', 'ModelData', 'ModelDataAdmin', 'ModelDataAdminUseCases', 'ModelDataComputeConfig', 'ModelFilter', 'ModelKindFilter', 'ModelOnline', 'ModelPlacementInput', 'ModelProviderDataInput', 'ModelServiceData', 'ModelServiceDataModel', 'ModelServiceDataModelBackbone', 'ModelServiceDisconnect', 'ModelServiceFilter', 'ModelserviceStatus', 'NvidiaProviderDataInput', 'OpenAIModel', 'OpenAIProviderDataInput', 'OrderPair', 'PrebuiltConfigInput', 'PrebuiltCriteriaKey', 'PrebuiltJudgeCreate', 'Protocol', 'ProviderName', 'RemoteConfigInput', 'RemoteEnvCreate', 'RemoteEnvData', 'RemoteEnvStatus', 'RemoveRemoteEnv', 'RemoveTeamMember', 'RemoveTeamMemberRemoveTeamMember', 'ResizePartitionInput', 'RoleCreate', 'SampleConfig', 'SelectionTypeInput', 'ShareUseCase', 'ShareUseCaseShareUseCase', 'SortDirection', 'SystemPromptTemplateCreate', 'SystemPromptTemplateUpdate', 'TeamCreate', 'TeamMemberRemove', 'TeamMemberSet', 'TerminateModel', 'TestRemoteEnv', 'TestRemoteEnvTestRemoteEnvRemoteEnvTestOffline', 'TestRemoteEnvTestRemoteEnvRemoteEnvTestOnline', 'TimeRange', 'TimeseriesInput', 'TimeseriesInterval', 'UnitConfigInput', 'UnitPosition', 'UnlinkMetric', 'UpdateCompletion', 'UpdateCustomRecipe', 'UpdateCustomRecipeUpdateCustomRecipe', 'UpdateGrader', 'UpdateGraderUpdateGrader', 'UpdateJudge', 'UpdateJudgeUpdateJudge', 'UpdateModel', 'UpdateModelComputeConfig', 'UpdateModelComputeConfigUpdateModelComputeConfig', 'UpdateModelService', 'UpdateModelUpdateModelService', 'UpdateRecipeInput', 'UpdateToolProviderInput', 'UpdateUser', 'UpdateUserSetTeamMember', 'UpdateUserSetTeamMemberRole', 'UpdateUserSetTeamMemberTeam', 'UpdateUserSetTeamMemberUser', 'Upload', 'UsageFilterInput', 'UsagePerUseCaseFilterInput', 'UseCaseCreate', 'UseCaseData', 'UseCaseDataMetrics', 'UseCaseDataModelServices', 'UseCaseDataShares', 'UseCaseDataSharesRole', 'UseCaseDataSharesTeam', 'UseCaseFilter', 'UseCaseMetadataInput', 'UseCaseSettingsInput', 'UseCaseShareInput', 'UseCaseShares', 'UseCaseUpdate', 'UserCreate', 'UserCreateTeamWithRole', 'UserData', 'UserDataTeams', 'UserDataTeamsRole', 'UserDataTeamsTeam', 'WidgetInput']


from typing import Dict
from .base_client import BaseSyncClient, BaseAsyncClient, UseCaseClient
from . import resources


class Adaptive(BaseSyncClient, UseCaseClient):
    def __init__(
        self,
        base_url: str,
        api_key: str | None = None,
        default_headers: Dict[str, str] | None = None,
    ) -> None:
        """
        Instantiates a new synchronous Adaptive client bounded to a use case.

        Args:
            use_case (str): A unique use case key; the client is bounded to this use case.
            base_url (str): The base URL for the Adaptive API.
            api_key (str, optional): API key for authentication.
                Defaults to None, in which case environment variable `ADAPTIVE_API_KEY` needs to be set.

        """
        super().__init__(base_url, api_key, default_headers)
        self.__use_case_key = None

        self.ab_tests: resources.ABTests = resources.ABTests(self)
        self.chat: resources.Chat = resources.Chat(self)
        self.compute_pools: resources.ComputePools = resources.ComputePools(self)
        self.recipes: resources.Recipes = resources.Recipes(self)
        self.datasets: resources.Datasets = resources.Datasets(self)
        self.embeddings: resources.Embeddings = resources.Embeddings(self)
        self.graders: resources.Graders = resources.Graders(self)
        self.jobs: resources.Jobs = resources.Jobs(self)
        self.feedback: resources.Feedback = resources.Feedback(self)
        self.interactions: resources.Interactions = resources.Interactions(self)
        self.models: resources.Models = resources.Models(self)
        self.permissions: resources.Permissions = resources.Permissions(self)
        self.roles: resources.Roles = resources.Roles(self)
        self.teams: resources.Teams = resources.Teams(self)
        self.use_cases: resources.UseCase = resources.UseCase(self)
        self.users: resources.Users = resources.Users(self)

    @property
    def default_use_case(self) -> str | None:
        """
        Get the current default use case key.
        """
        return self.__use_case_key

    def set_default_use_case(self, use_case: str) -> None:
        """
        Set a default use case key to be used for use case-specific operations.
        """
        if not (isinstance(use_case, str) and bool(use_case.strip())):
            raise ValueError("use_case must be a non-empty string")
        self.__use_case_key = use_case  # type: ignore[assignment]


class AsyncAdaptive(BaseAsyncClient, UseCaseClient):
    def __init__(
        self,
        base_url: str,
        api_key: str | None = None,
        default_headers: Dict[str, str] | None = None,
    ) -> None:
        """
        Instantiates a new asynchronous Adaptive client bounded to a use case.

        Args:
            use_case (str): A unique use case key; the client is bounded to this use case.
            base_url (str): The base URL for the Adaptive API.
            api_key (str, optional): API key for authentication.
                Defaults to None, in which case environment variable `ADAPTIVE_API_KEY` needs to be set.

        """
        super().__init__(base_url, api_key, default_headers)
        self.__use_case_key = None

        self.ab_tests: resources.AsyncABTests = resources.AsyncABTests(self)
        self.chat: resources.AsyncChat = resources.AsyncChat(self)
        self.compute_pools: resources.AsyncComputePools = resources.AsyncComputePools(self)
        self.recipes: resources.AsyncRecipes = resources.AsyncRecipes(self)
        self.datasets: resources.AsyncDatasets = resources.AsyncDatasets(self)
        self.embeddings: resources.AsyncEmbeddings = resources.AsyncEmbeddings(self)
        self.graders: resources.AsyncGraders = resources.AsyncGraders(self)
        self.jobs: resources.AsyncJobs = resources.AsyncJobs(self)
        self.feedback: resources.AsyncFeedback = resources.AsyncFeedback(self)
        self.interactions: resources.AsyncInteractions = resources.AsyncInteractions(self)
        self.models: resources.AsyncModels = resources.AsyncModels(self)
        self.permissions: resources.AsyncPermissions = resources.AsyncPermissions(self)
        self.roles: resources.AsyncRoles = resources.AsyncRoles(self)
        self.teams: resources.AsyncTeams = resources.AsyncTeams(self)
        self.use_cases: resources.AsyncUseCase = resources.AsyncUseCase(self)
        self.users: resources.AsyncUsers = resources.AsyncUsers(self)

    @property
    def default_use_case(self) -> str | None:
        """
        Get the current default use case key.
        """
        return self.__use_case_key

    def set_default_use_case(self, use_case: str) -> None:
        """
        Set a default use case key to be used for use case-specific operations.
        """
        if not isinstance(use_case, str):
            raise TypeError("use_case must be a string")
        if not use_case.strip():
            raise ValueError("use_case cannot be empty or whitespace")
        self.__use_case_key = use_case  # type: ignore[assignment]
